int main(signed *m, unsigned *p) {
  signed x;
  unsigned a;
  return x;
}
